#ifndef QOWNNOTES_PCH_H
#define QOWNNOTES_PCH_H

#if defined __cplusplus
/* Add C++ includes here */

#include <QDialog>
#include <QString>
#include <QPlainTextEdit>
#include <QWidget>
#include <QObject>
#include <QJsonObject>
#include <QDebug>
#include <QSettings>
#include <QMainWindow>
#include <QList>
#include <QVector>
#include <QHash>
#include <QStringList>
#include <QRegularExpression>
#include <QSyntaxHighlighter>
#include <QMetaType>
#include <QDir>
#include <QFileSystemWatcher>
#include <QMainWindow>
#include <QSystemTrayIcon>
#include <QTimer>
#include <QKeySequence>
#include <QPair>
#include <QLoggingCategory>
#include <QDateTime>
#include <QLabel>

#include <string>
#include <utility>

#endif

#endif // QOWNNOTES_PCH_H
